@@ -58,7 +58,7 @@ if __name__ =='__main__':
 
     print(sys.argv)
 
-    if not sys.argv[1] == 'silent':
+    if len(sys.argv) < 2 or not sys.argv[1] == 'silent':
         # use netstat -ano|findstr 5007 to check port use
         Timer(2, open_browser).start()
 
